<?php
/**
 * typos functions and definitions
 *
 * @package typos
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

if ( ! function_exists( 'typos_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function typos_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on typos, use a find and replace
	 * to change 'typos' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'typos', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'typos' ),
	) );

	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	/**
	 * Setup the WordPress core custom background feature.
	 */
	add_theme_support( 'custom-background', apply_filters( 'typos_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
	/*enable post thumbnails*/
	add_theme_support( 'post-thumbnails' );
}
endif; // typos_setup
add_action( 'after_setup_theme', 'typos_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function typos_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'typos' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'typos_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function typos_scripts() {
	wp_enqueue_style('typos-reset', get_template_directory_uri().'/reset.css' );
	wp_register_style('Quattrocento', '//fonts.googleapis.com/css?family=Quattrocento+Sans:regular');
	wp_enqueue_style( 'Quattrocento');
	wp_register_style('Inconsolata', '//fonts.googleapis.com/css?family=Inconsolata');
	wp_enqueue_style( 'Inconsolata');
	wp_register_style('fontAwesome', '//netdna.bootstrapcdn.com/font-awesome/3.2.1/css/font-awesome.css');
	wp_enqueue_style( 'fontAwesome');


	wp_enqueue_style( 'typos-style', get_stylesheet_uri() );

	wp_enqueue_script( 'typos-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'typos-main', get_template_directory_uri() . '/js/main.js', array(), '20120206', true );

	wp_enqueue_script( 'typos-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'typos-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'typos_scripts' );

if (!function_exists('typos_add_editor_styles')) {
	function typos_theme_add_editor_styles() {
    	add_editor_style( 'editor-style.css' );
	}
add_action( 'init', 'typos_theme_add_editor_styles' );	
}

if (!function_exists('typos_post_image_html')) {

	function typos_post_image_html( $html, $post_id, $post_image_id ) {

	  $html = '<a href="' . get_permalink( $post_id ) . '" title="' . esc_attr( get_the_title( $post_id ) ) . '">' . $html . '</a>';
	  return $html;

	}
	add_filter( 'post_thumbnail_html', 'typos_post_image_html', 10, 3 );
}


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

require( get_template_directory() . '/inc/custom-header.php' );

